@@ -1,19 +1,16 @@
-from .transform.base import TransformComponent
-from .transform.tokenize import TokenizeComponent
-from .transform.yake import YakeComponent
-from .transform.train_test import TrainTestComponent
-from .transform.array import ArrayTransformer
-
+from .dagster_types import DataFrameType, MLFlowRunType, ModelType, SeriesType
 from .inference.base import InferenceComponent
 from .inference.mlflow import MLFlowInferenceComponent
-
+from .loader.dataframe import DataFrameLoader
+from .resources.io_manager import io_manager
 from .training.base import TrainingComponent
+from .training.doc2vec import Doc2VecTrainingComponent
+from .training.grid_search import GridSearchTrainingComponent
 from .training.mlflow import MLFlowTrainingComponent
 from .training.sklearn import SklearnComponent
-from .training.grid_search import GridSearchTrainingComponent
-
-from .dagster_types import DataFrameType, SeriesType, ModelType, MLFlowRunType
-
-from .loader.dataframe import DataFrameLoader
-
-from .resources.io_manager import io_manager
+from .training.word2vec import Word2VecTrainingComponent
+from .transform.array import ArrayTransformer
+from .transform.base import TransformComponent
+from .transform.tokenize import TokenizeComponent
+from .transform.train_test import TrainTestComponent
+from .transform.yake import YakeComponent
