@@ -1,6 +1,3 @@
-import pandas as pd
-import dask.dataframe as dd
-from typing import Union
 from dagster import InputDefinition, OutputDefinition
 from qdk.base import BaseComponent
 from qdk.dagster_types import DataFrameType
@@ -8,14 +5,15 @@ from qdk.dagster_types import DataFrameType
 
 class TransformComponent(BaseComponent):
     compute_function = "transform"
-    tags = {"kind": "transform"}
-    input_defs = [InputDefinition("df", DataFrameType)]
-    output_defs = [OutputDefinition(DataFrameType, "df")]
-
-    @staticmethod
-    def _get_text_column_name(df: Union[pd.DataFrame, dd.DataFrame]) -> str:
-        text_column_name = df.attrs.get("text_column", "text")
-        return text_column_name
+    tags = {
+        "kind": "transform",
+    }
+    input_defs = [
+        InputDefinition("df", DataFrameType),
+    ]
+    output_defs = [
+        OutputDefinition(DataFrameType, "df"),
+    ]
 
     @classmethod
     def transform(cls, df: DataFrameType, **config) -> DataFrameType:
